@@ -1,8 +1,12 @@
 
+suppressWarnings(RNGversion("3.5.2"))
+
 library("trtf")
 library("survival")
 data("GBSG2", package = "TH.data")
 set.seed(290875)
+### Make UL and Windooze happy
+options(digits = 5)
 
 yvar <- numeric_var("y", support = c(100, 2000), bounds = c(0, Inf))
 By <- Bernstein_basis(yvar, order = 5, ui = "incre")
